"""CLI namespace."""

import click

from .parse import parse as _parse


@click.group()
def cli() -> None:
    """
    CLI for parsing the FPDS ATOM feed found at
    https://www.fpds.gov/fpdsng_cms/index.php/en/
    """


cli.add_command(_parse)
